package Bundle::CVSMonitor;

$VERSION = 1.06;

1;

__END__

=head1 NAME

Bundle::CVSMonitor - A bundle to install all CVSMonitor modules

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::CVSMonitor'>

=head1 CONTENTS

Array::Window

CGI

CGI::Carp          - For its fatalsToBrowser

Chart::Math::Axis  - Calculate correct graph axis

Clone

Class::Autouse     - Dynamic module loading

Class::Default

Class::Inspector   - Look at classes

Class::Handle      - Look at classes

Config::Tiny       - Config files

Date::Format       - Used to generate RSS content

File::Spec         - Path calculation

File::Copy

File::Flat         - Flat filesystem

File::Temp

File::Which

FindBin

GD::Graph          - Graphs

GD::Text

Getopt::Long       

HTTP::BrowserDetect

IO::File

Net::Telnet

Number::Compare    - Needed by Sort::Versions

Proc::ProcessTable

Scalar::Util

Sort::Versions     - Sort deep version numbers ( 1.2.3.4 )

Storable           - Freeze and load cache data

Text::Glob         - Needed by something else?

Time::Duration

Time::ParseDate

URI::Escape

Validate::Net

XML::Generator     - Used to generate RSS content

=head1 AUTHOR

Adam Kennedy (Maintainer), L<http://ali.as/>, cvsmonitor@ali.as

=cut
